@@ -195,6 +195,12 @@ static cpl_error_code amber_propertylist_append(cpl_propertylist * self,
 		case CPL_TYPE_POINTER:
 		case CPL_TYPE_FLOAT_COMPLEX:
 		case CPL_TYPE_DOUBLE_COMPLEX:
+		case CPL_TYPE_BITMASK:
+		case CPL_TYPE_COMPLEX:
+		case CPL_TYPE_LONG_LONG:
+		case CPL_TYPE_SHORT:
+		case CPL_TYPE_SIZE:
+		case CPL_TYPE_USHORT:
 		case CPL_TYPE_UNSPECIFIED:
 			/*case CPL_TYPE_COMPLEX: not anymode in CPL 3.0 */
 			break;
